@@ -17,10 +17,11 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-#  include <config.h>
-#endif
 
+#include <config.h>
+
+#include <gnome.h>
+#include <gtk/gtk.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
@@ -36,159 +37,106 @@
 #include "infoview.h"
 #include "procactions.h"
 #include "load-graph.h"
-#include "cellrenderer.h"
 #include "util.h"
 
-static void	cb_toggle_tree (GtkMenuItem *menuitem, gpointer data);
-static void	cb_toggle_threads (GtkMenuItem *menuitem, gpointer data);
+static void	cb_toggle_tree (GtkAction *action, gpointer data);
+static void	cb_toggle_threads (GtkAction *action, gpointer data);
 
-
-static GnomeUIInfo file1_menu_uiinfo[] =
+static const GtkActionEntry menu_entries[] =
 {
-	GNOMEUIINFO_MENU_QUIT_ITEM (cb_app_exit, NULL),
-	GNOMEUIINFO_END
+	{ "File", NULL, N_("_File") },
+	{ "Edit", NULL, N_("_Edit") },
+	{ "View", NULL, N_("_View") },
+	{ "Help", NULL, N_("_Help") },
+
+	{ "Quit", GTK_STOCK_QUIT, N_("_Quit"), "<control>Q",
+	  N_("Quit the program"), G_CALLBACK (cb_app_exit) },
+
+	{ "EndProcess", NULL, N_("End _Process"), "<control>E",
+	  N_("Force process to finish normally"), G_CALLBACK (cb_end_process) },
+	{ "KillProcess", NULL, N_("_Kill Process"), "<control>K",
+	  N_("Force process to finish immediately"), G_CALLBACK (cb_kill_process) },
+	{ "ChangePriority", NULL, N_("_Change Priority..."), "<control>R",
+	  N_("Change the order of priority of process"), G_CALLBACK (cb_renice) },
+	{ "Preferencies", GTK_STOCK_PREFERENCES, N_("Prefere_nces"), NULL,
+	  N_("Configure the application"), G_CALLBACK (cb_edit_preferences) },
+
+	{ "HideProcess", NULL, N_("_Hide Process"), "<control>H",
+	  N_("Hide process from list"), G_CALLBACK (cb_hide_process) },
+	{ "HiddenProcesses", NULL, N_("_Hidden Processes"), "<control>P",
+	  N_("Open the list of currently hidden processes"), G_CALLBACK (cb_show_hidden_processes) },
+	{ "MemoryMaps", NULL, N_("_Memory Maps"), "<control>M",
+	  N_("Open the memory maps associated with a process"), G_CALLBACK (cb_show_memory_maps) },
+	{ "OpenFiles", NULL, N_("Open _Files"), "<control>F",
+	  N_("View the files opened by a process"), G_CALLBACK (cb_show_open_files) },
+
+	{ "HelpContents", GTK_STOCK_HELP, N_("_Contents"), "F1",
+	  N_("Open the manual"), G_CALLBACK (cb_help_contents) },
+	{ "About", GTK_STOCK_ABOUT, N_("_About"), NULL,
+	  N_("About this application"), G_CALLBACK (cb_about) }
 };
 
-static GnomeUIInfo edit1_menu_uiinfo[] =
+static const GtkToggleActionEntry toggle_menu_entries[] =
 {
-	{
-	 GNOME_APP_UI_ITEM, N_("End _Process"), N_("Force process to finish normally"),
-	 cb_end_process, NULL, NULL, 0, NULL,
-	 'e', GDK_CONTROL_MASK
-	},
-	{
-	 GNOME_APP_UI_ITEM, N_("_Kill Process"), N_("Force process to finish immediately"),
-	 cb_kill_process, NULL, NULL, 0, NULL,
-	 'k', GDK_CONTROL_MASK
-	},
-	GNOMEUIINFO_SEPARATOR,
- 	{
- 	  GNOME_APP_UI_ITEM, N_("_Change Priority..."), N_("Change the order of priority of process"),
-	 cb_renice, NULL, NULL, 0, NULL,
-	 'r', GDK_CONTROL_MASK
-	},
-	GNOMEUIINFO_SEPARATOR,
-	GNOMEUIINFO_MENU_PREFERENCES_ITEM (cb_preferences_activate, NULL),
-	GNOMEUIINFO_END
+	{ "ShowDependencies", NULL, N_("_Dependencies"), "<control>D",
+	  N_("Show parent/child relationship between processes"),
+	  G_CALLBACK (cb_toggle_tree), TRUE },
+	{ "ShowThreads", NULL, N_("_Threads"), "<control>T",
+	  N_("Show each thread as a separate process"),
+	  G_CALLBACK (cb_toggle_threads), FALSE }
 };
 
-static GnomeUIInfo view1_menu_uiinfo[] =
-{
-	{
-	 GNOME_APP_UI_TOGGLEITEM, N_("_Dependencies"), N_("Show parent/child relationship between processes"),
-	 cb_toggle_tree, NULL, NULL, 0, NULL,
-	 'd', GDK_CONTROL_MASK
-	}, 
-	{
-	 GNOME_APP_UI_TOGGLEITEM, N_("_Threads"), N_("Show each thread as a separate process"),
-	 cb_toggle_threads, NULL, NULL, 0, NULL,
-	 't', GDK_CONTROL_MASK
-	},
-	GNOMEUIINFO_SEPARATOR,
-	{
-	 GNOME_APP_UI_ITEM, N_("_Hide Process"), N_("Hide process from list"),
-	 cb_hide_process, NULL, NULL, 0, NULL,
-	 'h', GDK_CONTROL_MASK
-	}, 
-	{
-	 GNOME_APP_UI_ITEM, N_("_Hidden Processes"), N_("Open the list of currently hidden processes"),
-	 cb_show_hidden_processes, NULL, NULL, 0, NULL,
-	 'p', GDK_CONTROL_MASK
-	},
-	GNOMEUIINFO_SEPARATOR,
-	{
-	 GNOME_APP_UI_ITEM, N_("_Memory Maps"), N_("Open the memory maps associated with a process"),
-	 cb_show_memory_maps, NULL, NULL, 0, NULL,
-	 'm', GDK_CONTROL_MASK
-	},
-	{
-	 GNOME_APP_UI_ITEM, N_("Open _Files"), N_("View the files opened by a process"),
-	 cb_show_open_files, NULL, NULL, 0, 0,
-	 'f', GDK_CONTROL_MASK
-	},
-	GNOMEUIINFO_END
-};
+static const char ui_info[] =
+"  <menubar name=\"MenuBar\">"
+"    <menu name=\"FileMenu\" action=\"File\">"
+"      <menuitem name=\"FileQuitMenu\" action=\"Quit\" />"
+"    </menu>"
+"    <menu name=\"EditMenu\" action=\"Edit\">"
+"      <menuitem name=\"EditEndProcessMenu\" action=\"EndProcess\" />"
+"      <menuitem name=\"EditKillProcessMenu\" action=\"KillProcess\" />"
+"      <separator />"
+"      <menuitem name=\"EditChangePriorityMenu\" action=\"ChangePriority\" />"
+"      <separator />"
+"      <menuitem name=\"EditPreferenciesMenu\" action=\"Preferencies\" />"
+"    </menu>"
+"    <menu name=\"ViewMenu\" action=\"View\">"
+"      <menuitem name=\"ViewDependenciesMenu\" action=\"ShowDependencies\" />"
+"      <menuitem name=\"ViewThreadsMenu\" action=\"ShowThreads\" />"
+"      <separator />"
+"      <menuitem name=\"ViewHideProcessMenu\" action=\"HideProcess\" />"
+"      <menuitem name=\"ViewHiddenProcessesMenu\" action=\"HiddenProcesses\" />"
+"      <separator />"
+"      <menuitem name=\"ViewMemoryMapsMenu\" action=\"MemoryMaps\" />"
+"      <menuitem name=\"ViewOpenFilesMenu\" action=\"OpenFiles\" />"
+"    </menu>"
+"    <menu name=\"HelpMenu\" action=\"Help\">"
+"      <menuitem name=\"HelpContentsMenu\" action=\"HelpContents\" />"
+"      <menuitem name=\"HelpAboutMenu\" action=\"About\" />"
+"    </menu>"
+"  </menubar>"
+"  <popup name=\"PopupMenu\" action=\"Popup\">"
+"    <menuitem action=\"EndProcess\" />"
+"    <menuitem action=\"KillProcess\" />"
+"    <separator />"
+"    <menuitem action=\"ChangePriority\" />"
+"    <separator />"
+"    <menuitem action=\"HideProcess\" />"
+"    <separator />"
+"    <menuitem action=\"MemoryMaps\" />"
+"    <menuitem action=\"OpenFiles\" />"
+"  </popup>";
 
-static GnomeUIInfo help1_menu_uiinfo[] =
-{
-	GNOMEUIINFO_HELP("gnome-system-monitor"),
-	GNOMEUIINFO_MENU_ABOUT_ITEM (cb_about_activate, NULL),
-	GNOMEUIINFO_END
-};
-
-static GnomeUIInfo menubar1_uiinfo[] =
-{
-	GNOMEUIINFO_MENU_FILE_TREE (file1_menu_uiinfo),
-	GNOMEUIINFO_MENU_EDIT_TREE (edit1_menu_uiinfo),
-	GNOMEUIINFO_MENU_VIEW_TREE (view1_menu_uiinfo),
-	GNOMEUIINFO_MENU_HELP_TREE (help1_menu_uiinfo),
-	GNOMEUIINFO_END
-};
-
-static GnomeUIInfo popup_menu_uiinfo[] =
-{
-	{
- 	  GNOME_APP_UI_ITEM, N_("_End Process"), N_("Force a process to finish normally"),
-	 cb_end_process, NULL, NULL, 0, NULL,
-	 0, 0
-	},
-	{
- 	  GNOME_APP_UI_ITEM, N_("_Kill Process"), N_("Force a process to finish immediately"),
-	 cb_kill_process, NULL, NULL, 0, NULL,
-	 0, 0
-	},
-	GNOMEUIINFO_SEPARATOR,
-	{
- 	  GNOME_APP_UI_ITEM, N_("_Change Priority..."), N_("Change the order of priority of process"),
-	 cb_renice, NULL, NULL, 0, NULL,
-	 0, 0
-	},
-	GNOMEUIINFO_SEPARATOR,
-	{
- 	  GNOME_APP_UI_ITEM, N_("_Hide Process"), N_("Hide process from list"),
-	 cb_hide_process, NULL, NULL, 0, NULL,
-	 0, 0
-	},
-	GNOMEUIINFO_SEPARATOR,
-	{
- 	  GNOME_APP_UI_ITEM, N_("_Memory Maps"), N_("Open the memory maps associated with the process"),
-	 cb_show_memory_maps, NULL, NULL, 0, NULL,
-	 0, 0
-	},
-	{
- 	  GNOME_APP_UI_ITEM, N_("Open _Files"), N_("View the files opened by the process"),
-	 popup_menu_show_open_files, NULL, NULL, 0, 0,
-	 0, 0
-	},
-	GNOMEUIINFO_END
-};
-
-
-static GtkWidget *infolabel = NULL;
-static GtkWidget *endprocessbutton = NULL;
-static GtkWidget *popup_menu = NULL;
-static GtkWidget *sys_pane = NULL;
-
-
-gint
-get_sys_pane_pos (void)
-{
-	return GTK_PANED (sys_pane)->child1_size;
-}
 
 static GtkWidget *
 create_proc_view (ProcData *procdata)
 {
-	GtkWidget *vbox1;
+	GtkWidget *vbox1, *vbox2;
 	GtkWidget *hbox1;
-	GtkWidget *search_label;
-	GtkWidget *search_entry;
 	GtkWidget *proc_combo;
 	GtkWidget *scrolled;
-	GtkWidget *infobox;
 	GtkWidget *label;
 	GtkWidget *hbox2;
-	GtkWidget *infobutton;
+	char* string;
 
 	vbox1 = gtk_vbox_new (FALSE, 18);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox1), 12);
@@ -196,14 +144,10 @@ create_proc_view (ProcData *procdata)
 	hbox1 = gtk_hbox_new (FALSE, 12);
 	gtk_box_pack_start (GTK_BOX (vbox1), hbox1, FALSE, FALSE, 0);
 
-	search_label = gtk_label_new_with_mnemonic (_("Sea_rch:"));
-	gtk_box_pack_start (GTK_BOX (hbox1), search_label, FALSE, FALSE, 0);
-	
-	search_entry = gtk_entry_new ();
-	gtk_box_pack_start (GTK_BOX (hbox1), search_entry, FALSE, FALSE, 0);
-	g_signal_connect (G_OBJECT (search_entry), "activate",
-			  G_CALLBACK (cb_search), procdata);
-	gtk_label_set_mnemonic_widget (GTK_LABEL (search_label), search_entry);
+	string = make_loadavg_string ();
+	procdata->loadavg = gtk_label_new (string);
+	g_free (string);
+	gtk_box_pack_start (GTK_BOX (hbox1), procdata->loadavg, FALSE, FALSE, 0);
 
 	proc_combo = gtk_combo_box_new_text ();
 	gtk_box_pack_end (GTK_BOX (hbox1), proc_combo, FALSE, FALSE, 0);
@@ -233,31 +177,26 @@ create_proc_view (ProcData *procdata)
 	
 	gtk_widget_show_all (scrolled);
 	
-	infobox = infoview_create (procdata);
-	gtk_box_pack_start (GTK_BOX (vbox1), infobox, FALSE, FALSE, 0);
-
 	hbox2 = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (vbox1), hbox2, FALSE, FALSE, 0);
-	
-	endprocessbutton = gtk_button_new_with_mnemonic (_("End _Process"));
-  	gtk_box_pack_end (GTK_BOX (hbox2), endprocessbutton, FALSE, FALSE, 0);
-	g_signal_connect (G_OBJECT (endprocessbutton), "clicked",
-			  G_CALLBACK (cb_end_process_button_pressed), procdata);
 
-	infolabel = gtk_label_new_with_mnemonic (_("More _Info"));
-	infobutton = gtk_button_new ();
-	gtk_container_add (GTK_CONTAINER (infobutton), infolabel);
-	gtk_box_pack_start (GTK_BOX (hbox2), infobutton, FALSE, FALSE, 0);
-	g_signal_connect (G_OBJECT (infobutton), "clicked",
-			  G_CALLBACK (cb_info_button_pressed), procdata);
+	infoview_create (procdata);
+	gtk_box_pack_start (GTK_BOX (hbox2), procdata->infoview.expander, FALSE, FALSE, 0);
+	gtk_expander_set_expanded (GTK_EXPANDER(procdata->infoview.expander),
+				   procdata->config.show_more_info);
+	gtk_widget_show (procdata->infoview.expander);
+	
+	vbox2 = gtk_vbox_new (FALSE, 0);
+	gtk_box_pack_end (GTK_BOX (hbox2), vbox2, FALSE, FALSE, 0);
+	procdata->endprocessbutton = gtk_button_new_with_mnemonic (_("End _Process"));
+	gtk_box_pack_end (GTK_BOX (vbox2), procdata->endprocessbutton, FALSE, FALSE, 0);
+	g_signal_connect (G_OBJECT (procdata->endprocessbutton), "clicked",
+			  G_CALLBACK (cb_end_process_button_pressed), procdata);
 	
 	gtk_widget_show_all (hbox2);
 	
 	/* create popup_menu */
- 	popup_menu = gtk_menu_new ();
- 	gnome_app_fill_menu_with_data (GTK_MENU_SHELL (popup_menu), popup_menu_uiinfo,
-  			               NULL, TRUE, 0, procdata);
-	gtk_widget_show (popup_menu);
+ 	procdata->popup_menu = gtk_ui_manager_get_widget (procdata->uimanager, "/PopupMenu");
 
         return vbox1;
 }
@@ -289,7 +228,7 @@ sort_bytes (GtkTreeModel *model, GtkTreeIter *itera, GtkTreeIter *iterb, gpointe
 	}
 }
 
-static GtkWidget *
+GtkWidget *
 make_title_label (const char *text)
 {
   GtkWidget *label;
@@ -299,7 +238,7 @@ make_title_label (const char *text)
   label = gtk_label_new (full);
   g_free (full);
 
-  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+  gtk_misc_set_alignment (GTK_MISC (label), 0.0f, 0.5f);
   gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 
   return label;
@@ -313,23 +252,20 @@ cpu_size_request (GtkWidget *box, GtkRequisition *req, ProcData *procdata)
 		MAX(req->width, procdata->cpu_label_fixed_width);
 }
 
-static GtkWidget *
-create_sys_view (ProcData *procdata)
+
+
+
+static GtkWidget*
+create_disk_view (ProcData *procdata)
 {
-	GtkWidget *vbox, *hbox;
-	GtkWidget *vpane;
-	GtkWidget *cpu_box, *mem_box, *disk_box;
-	GtkWidget *cpu_hbox, *mem_hbox, *disk_hbox;
-	GtkWidget *cpu_graph_box, *mem_graph_box;
-	GtkWidget *label,*cpu_label, *spacer;
-	GtkWidget *table;
-	GtkWidget *color_picker;
+	GtkWidget *disk_box, *disk_hbox;
+	GtkWidget *label, *spacer;
 	GtkWidget *scrolled;
 	GtkWidget *disk_tree;
 	GtkTreeStore *model;
 	GtkTreeViewColumn *col;
 	GtkCellRenderer *cell;
-	GtkSizeGroup *sizegroup;
+	gint i;
 
 	static const gchar *titles[] = {
 	  N_("Device"),
@@ -340,186 +276,12 @@ create_sys_view (ProcData *procdata)
 	  N_("Used"),
 	};
 
-	LoadGraph *cpu_graph, *mem_graph;
-	gint i;
-
 	PROCMAN_GETTEXT_ARRAY_INIT(titles);
-	
-	vpane = gtk_vpaned_new ();
-	sys_pane = vpane;
-	gtk_paned_set_position (GTK_PANED (vpane), procdata->config.pane_pos);
-	
-	gtk_container_set_border_width (GTK_CONTAINER (vpane), 6);
-
-	vbox = gtk_vbox_new (FALSE, 18);
-	gtk_paned_pack1 (GTK_PANED (vpane), vbox, FALSE, FALSE);
-
-	gtk_container_set_border_width (GTK_CONTAINER (vbox), 6);
-
-	/* The CPU BOX */
-
-	cpu_box = gtk_vbox_new (FALSE, 6);
-	gtk_box_pack_start (GTK_BOX (vbox), cpu_box, TRUE, TRUE, 0);
-
-	label = make_title_label (_("CPU History"));
-	gtk_widget_show (label);
-	gtk_box_pack_start (GTK_BOX (cpu_box), label, FALSE, FALSE, 0);
-	
-	cpu_hbox = gtk_hbox_new (FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (cpu_box), cpu_hbox, TRUE, TRUE, 0);
-
-	spacer = gtk_label_new ("    ");
-	gtk_box_pack_start (GTK_BOX (cpu_hbox), spacer, FALSE, FALSE, 0);
-
-	cpu_graph_box = gtk_vbox_new (FALSE, 6);
-	gtk_box_pack_start (GTK_BOX (cpu_hbox), cpu_graph_box, TRUE, TRUE, 0);
-
-	cpu_graph = load_graph_new (LOAD_GRAPH_CPU, procdata);
-	gtk_box_pack_start (GTK_BOX (cpu_graph_box), cpu_graph->main_widget, TRUE, TRUE, 0);
-
-	sizegroup = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
-
-	hbox = gtk_hbox_new (FALSE, 12);
-	gtk_box_pack_start (GTK_BOX (cpu_graph_box), hbox, FALSE, FALSE, 0);
-
-	for (i=0;i<procdata->config.num_cpus; i++) {
-		GtkWidget *temp_hbox;
-		gchar *text;
-		
-		temp_hbox = gtk_hbox_new (FALSE, 6);
-		gtk_box_pack_start (GTK_BOX (hbox), temp_hbox, FALSE, FALSE, 0);
-		gtk_size_group_add_widget (sizegroup, temp_hbox);
-		g_signal_connect (G_OBJECT (temp_hbox), "size_request",
-					 G_CALLBACK (cpu_size_request), procdata);
-		
-		color_picker = gnome_color_picker_new ();
-		gnome_color_picker_set_i16 (GNOME_COLOR_PICKER (color_picker), 
-				    cpu_graph->colors[2+i].red,
-				    cpu_graph->colors[2+i].green,
-				    cpu_graph->colors[2+i].blue, 0);
-		g_signal_connect (G_OBJECT (color_picker), "color_set",
-			    G_CALLBACK (cb_cpu_color_changed), GINT_TO_POINTER (i));
-		gtk_box_pack_start (GTK_BOX (temp_hbox), color_picker, FALSE, FALSE, 0);
-		
-		text = g_strdup_printf (_("CPU%d:"), i+1);
-		label = gtk_label_new (text);
-		gtk_box_pack_start (GTK_BOX (temp_hbox), label, FALSE, FALSE, 0);
-		g_free (text);
-		
-		cpu_label = gtk_label_new (NULL);
-		gtk_box_pack_start (GTK_BOX (temp_hbox), cpu_label, FALSE, FALSE, 0);
-		cpu_graph->cpu_labels[i] = cpu_label;
-		
-	}
-	
-	
-	
-	procdata->cpu_graph = cpu_graph;
-
-
-	mem_box = gtk_vbox_new (FALSE, 6);
-	gtk_box_pack_start (GTK_BOX (vbox), mem_box, TRUE, TRUE, 0);
-
-	label = make_title_label (_("Memory and Swap History"));
-	gtk_widget_show (label);
-	gtk_box_pack_start (GTK_BOX (mem_box), label, FALSE, FALSE, 0);
-	
-	mem_hbox = gtk_hbox_new (FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (mem_box), mem_hbox, TRUE, TRUE, 0);
-
-	spacer = gtk_label_new ("    ");
-	gtk_box_pack_start (GTK_BOX (mem_hbox), spacer, FALSE, FALSE, 0);
-
-	mem_graph_box = gtk_vbox_new (FALSE, 6);
-	gtk_box_pack_start (GTK_BOX (mem_hbox), mem_graph_box, TRUE, TRUE, 0);
-
-
-	mem_graph = load_graph_new (LOAD_GRAPH_MEM, procdata);
-	gtk_box_pack_start (GTK_BOX (mem_graph_box), mem_graph->main_widget, 
-			    TRUE, TRUE, 0);
-	
-	table = gtk_table_new (2, 7, FALSE);
-	gtk_table_set_row_spacings (GTK_TABLE (table), 6);
-	gtk_table_set_col_spacings (GTK_TABLE (table), 12);
-	gtk_box_pack_start (GTK_BOX (mem_graph_box), table, 
-			    FALSE, FALSE, 0);
-
-	color_picker = gnome_color_picker_new ();
-	gnome_color_picker_set_i16 (GNOME_COLOR_PICKER (color_picker), 
-				    mem_graph->colors[2].red,
-				    mem_graph->colors[2].green,
-				    mem_graph->colors[2].blue, 0);
-	g_signal_connect (G_OBJECT (color_picker), "color_set",
-			    G_CALLBACK (cb_mem_color_changed), procdata);
-	gtk_table_attach (GTK_TABLE (table), color_picker, 0, 1, 0, 1, 0, 0, 0, 0);
-	
-	label = gtk_label_new (_("User memory:"));
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach (GTK_TABLE (table), label, 1, 2, 0, 1, GTK_FILL, 0, 0, 0);
-	
-	mem_graph->memused_label = gtk_label_new ("");
-	gtk_misc_set_alignment (GTK_MISC (mem_graph->memused_label), 0.0, 0.5);
-	gtk_table_attach (GTK_TABLE (table), mem_graph->memused_label, 2, 3, 0, 1, 
-			  GTK_FILL, 0, 0, 0);
-	
-	label = gtk_label_new (_("of"));
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach (GTK_TABLE (table), label, 3, 4, 0, 1, GTK_FILL, 0, 0, 0);
-	
-	mem_graph->memtotal_label = gtk_label_new ("");
-	gtk_misc_set_alignment (GTK_MISC (mem_graph->memtotal_label), 0.0, 0.5);
-	gtk_table_attach (GTK_TABLE (table), mem_graph->memtotal_label, 4, 5, 0, 1, 
-			  GTK_FILL, 0, 0, 0);
-	
-	mem_graph->mempercent_label = gtk_label_new ("");
-	gtk_misc_set_alignment (GTK_MISC (mem_graph->mempercent_label), 1.0, 0.5);
-	gtk_table_attach (GTK_TABLE (table), mem_graph->mempercent_label, 5, 6, 0, 1, 
-			  GTK_FILL, 0, 0, 0);
-			  
-	color_picker = gnome_color_picker_new ();
-	gnome_color_picker_set_i16 (GNOME_COLOR_PICKER (color_picker), 
-				    mem_graph->colors[3].red,
-				    mem_graph->colors[3].green,
-				    mem_graph->colors[3].blue, 0);
-	g_signal_connect (G_OBJECT (color_picker), "color_set",
-			    G_CALLBACK (cb_swap_color_changed), procdata);
-	gtk_table_attach (GTK_TABLE (table), color_picker, 0, 1, 1, 2, 0, 0, 0, 0);
-			  
-	label = gtk_label_new (_("Used swap:"));
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach (GTK_TABLE (table), label, 1, 2, 1, 2, GTK_FILL, 0, 0, 0);
-	
-	mem_graph->swapused_label = gtk_label_new ("");
-	gtk_misc_set_alignment (GTK_MISC (mem_graph->swapused_label), 0.0, 0.5);
-	gtk_table_attach (GTK_TABLE (table), mem_graph->swapused_label, 2, 3, 1, 2, 
-			  GTK_FILL, 0, 0, 0);
-			  
-	label = gtk_label_new (_("of"));
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach (GTK_TABLE (table), label, 3, 4, 1, 2, GTK_FILL, 0, 0, 0);
-	
-	mem_graph->swaptotal_label = gtk_label_new ("");
-	gtk_misc_set_alignment (GTK_MISC (mem_graph->swaptotal_label), 0.0, 0.5);
-	gtk_table_attach (GTK_TABLE (table), mem_graph->swaptotal_label, 4, 5, 1, 2, 
-			  GTK_FILL, 0, 0, 0);	
-	
-	mem_graph->swappercent_label = gtk_label_new ("");
-	gtk_misc_set_alignment (GTK_MISC (mem_graph->swappercent_label), 1.0, 0.5);
-	gtk_table_attach (GTK_TABLE (table), mem_graph->swappercent_label, 5, 6, 1, 2, 
-			  GTK_FILL, 0, 0, 0);
-			  
-	procdata->mem_graph = mem_graph;
-	gtk_widget_show_all (vbox);
-
-
-	/*****************************************/
 
 	disk_box = gtk_vbox_new (FALSE, 6);
 
 	gtk_container_set_border_width (GTK_CONTAINER (disk_box), 6);
 
-	gtk_paned_pack2 (GTK_PANED (vpane), disk_box, TRUE, TRUE);
-
 	label = make_title_label (_("Devices"));
 	gtk_box_pack_start (GTK_BOX (disk_box), label, FALSE, FALSE, 0);
 
@@ -594,7 +356,7 @@ create_sys_view (ProcData *procdata)
 	gtk_tree_view_column_set_title (col, titles[5]);
 		
 	
-	cell = procman_cell_renderer_progress_new ();
+	cell = gtk_cell_renderer_progress_new ();
 	gtk_tree_view_column_pack_start (col, cell, TRUE);
 	gtk_tree_view_column_set_attributes (col, cell,
 					     "value", 7,
@@ -621,33 +383,320 @@ create_sys_view (ProcData *procdata)
   						  cb_update_disks, procdata);
 
 
-	return vpane;
+	return disk_box;
 }
 
 
+
+
+
+
+
+static GtkWidget *
+create_sys_view (ProcData *procdata)
+{
+	GtkWidget *vbox, *hbox;
+	GtkWidget *cpu_box, *mem_box;
+	GtkWidget *cpu_hbox, *mem_hbox;
+	GtkWidget *cpu_graph_box, *mem_graph_box;
+	GtkWidget *label,*cpu_label, *spacer;
+	GtkWidget *table;
+	GtkWidget *color_picker;
+	GtkSizeGroup *sizegroup;
+	GdkColor color;
+	LoadGraph *cpu_graph, *mem_graph;
+	gint i;
+
+
+	vbox = gtk_vbox_new (FALSE, 18);
+
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), 6);
+
+	/* The CPU BOX */
+
+	cpu_box = gtk_vbox_new (FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (vbox), cpu_box, TRUE, TRUE, 0);
+
+	label = make_title_label (_("CPU History"));
+	gtk_widget_show (label);
+	gtk_box_pack_start (GTK_BOX (cpu_box), label, FALSE, FALSE, 0);
+	
+	cpu_hbox = gtk_hbox_new (FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (cpu_box), cpu_hbox, TRUE, TRUE, 0);
+
+	spacer = gtk_label_new ("    ");
+	gtk_box_pack_start (GTK_BOX (cpu_hbox), spacer, FALSE, FALSE, 0);
+
+	cpu_graph_box = gtk_vbox_new (FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (cpu_hbox), cpu_graph_box, TRUE, TRUE, 0);
+
+	cpu_graph = load_graph_new (LOAD_GRAPH_CPU, procdata);
+	gtk_box_pack_start (GTK_BOX (cpu_graph_box), cpu_graph->main_widget, TRUE, TRUE, 0);
+
+	sizegroup = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
+
+	hbox = gtk_hbox_new (FALSE, 12);
+	gtk_box_pack_start (GTK_BOX (cpu_graph_box), hbox, FALSE, FALSE, 0);
+
+	for (i=0;i<procdata->config.num_cpus; i++) {
+		GtkWidget *temp_hbox;
+		gchar *text;
+		
+		temp_hbox = gtk_hbox_new (FALSE, 6);
+		gtk_box_pack_start (GTK_BOX (hbox), temp_hbox, FALSE, FALSE, 0);
+		gtk_size_group_add_widget (sizegroup, temp_hbox);
+		g_signal_connect (G_OBJECT (temp_hbox), "size_request",
+					 G_CALLBACK (cpu_size_request), procdata);
+
+		color.red   = cpu_graph->colors[2+i].red;
+		color.green = cpu_graph->colors[2+i].green;
+		color.blue  = cpu_graph->colors[2+i].blue;
+		color_picker = gtk_color_button_new_with_color (&color);
+
+		g_signal_connect (G_OBJECT (color_picker), "color_set",
+			    G_CALLBACK (cb_cpu_color_changed), GINT_TO_POINTER (i));
+		gtk_box_pack_start (GTK_BOX (temp_hbox), color_picker, FALSE, FALSE, 0);
+		
+		text = g_strdup_printf (_("CPU%d:"), i+1);
+		label = gtk_label_new (text);
+		gtk_box_pack_start (GTK_BOX (temp_hbox), label, FALSE, FALSE, 0);
+		g_free (text);
+		
+		cpu_label = gtk_label_new (NULL);
+		gtk_box_pack_start (GTK_BOX (temp_hbox), cpu_label, FALSE, FALSE, 0);
+		cpu_graph->cpu_labels[i] = cpu_label;
+		
+	}
+	
+	
+	
+	procdata->cpu_graph = cpu_graph;
+
+
+	mem_box = gtk_vbox_new (FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (vbox), mem_box, TRUE, TRUE, 0);
+
+	label = make_title_label (_("Memory and Swap History"));
+	gtk_widget_show (label);
+	gtk_box_pack_start (GTK_BOX (mem_box), label, FALSE, FALSE, 0);
+	
+	mem_hbox = gtk_hbox_new (FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (mem_box), mem_hbox, TRUE, TRUE, 0);
+
+	spacer = gtk_label_new ("    ");
+	gtk_box_pack_start (GTK_BOX (mem_hbox), spacer, FALSE, FALSE, 0);
+
+	mem_graph_box = gtk_vbox_new (FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (mem_hbox), mem_graph_box, TRUE, TRUE, 0);
+
+
+	mem_graph = load_graph_new (LOAD_GRAPH_MEM, procdata);
+	gtk_box_pack_start (GTK_BOX (mem_graph_box), mem_graph->main_widget, 
+			    TRUE, TRUE, 0);
+	
+	table = gtk_table_new (2, 7, FALSE);
+	gtk_table_set_row_spacings (GTK_TABLE (table), 6);
+	gtk_table_set_col_spacings (GTK_TABLE (table), 12);
+	gtk_box_pack_start (GTK_BOX (mem_graph_box), table, 
+			    FALSE, FALSE, 0);
+
+
+	color.red   = mem_graph->colors[2].red;
+	color.green = mem_graph->colors[2].green;
+	color.blue  = mem_graph->colors[2].blue;
+	color_picker = gtk_color_button_new_with_color (&color);
+	g_signal_connect (G_OBJECT (color_picker), "color_set",
+			    G_CALLBACK (cb_mem_color_changed), procdata);
+	gtk_table_attach (GTK_TABLE (table), color_picker, 0, 1, 0, 1, 0, 0, 0, 0);
+	
+	label = gtk_label_new (_("User memory:"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+	gtk_table_attach (GTK_TABLE (table), label, 1, 2, 0, 1, GTK_FILL, 0, 0, 0);
+	
+	mem_graph->memused_label = gtk_label_new ("");
+	gtk_misc_set_alignment (GTK_MISC (mem_graph->memused_label), 0.0, 0.5);
+	gtk_table_attach (GTK_TABLE (table), mem_graph->memused_label, 2, 3, 0, 1, 
+			  GTK_FILL, 0, 0, 0);
+	
+	label = gtk_label_new (_("of"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+	gtk_table_attach (GTK_TABLE (table), label, 3, 4, 0, 1, GTK_FILL, 0, 0, 0);
+	
+	mem_graph->memtotal_label = gtk_label_new ("");
+	gtk_misc_set_alignment (GTK_MISC (mem_graph->memtotal_label), 0.0, 0.5);
+	gtk_table_attach (GTK_TABLE (table), mem_graph->memtotal_label, 4, 5, 0, 1, 
+			  GTK_FILL, 0, 0, 0);
+	
+	mem_graph->mempercent_label = gtk_label_new ("");
+	gtk_misc_set_alignment (GTK_MISC (mem_graph->mempercent_label), 1.0, 0.5);
+	gtk_table_attach (GTK_TABLE (table), mem_graph->mempercent_label, 5, 6, 0, 1, 
+			  GTK_FILL, 0, 0, 0);
+			  
+	color.red   = mem_graph->colors[3].red;
+	color.green = mem_graph->colors[3].green;
+	color.blue  = mem_graph->colors[3].blue;
+	color_picker = gtk_color_button_new_with_color (&color);
+	g_signal_connect (G_OBJECT (color_picker), "color_set",
+			    G_CALLBACK (cb_swap_color_changed), procdata);
+	gtk_table_attach (GTK_TABLE (table), color_picker, 0, 1, 1, 2, 0, 0, 0, 0);
+			  
+	label = gtk_label_new (_("Used swap:"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+	gtk_table_attach (GTK_TABLE (table), label, 1, 2, 1, 2, GTK_FILL, 0, 0, 0);
+	
+	mem_graph->swapused_label = gtk_label_new ("");
+	gtk_misc_set_alignment (GTK_MISC (mem_graph->swapused_label), 0.0, 0.5);
+	gtk_table_attach (GTK_TABLE (table), mem_graph->swapused_label, 2, 3, 1, 2, 
+			  GTK_FILL, 0, 0, 0);
+			  
+	label = gtk_label_new (_("of"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+	gtk_table_attach (GTK_TABLE (table), label, 3, 4, 1, 2, GTK_FILL, 0, 0, 0);
+	
+	mem_graph->swaptotal_label = gtk_label_new ("");
+	gtk_misc_set_alignment (GTK_MISC (mem_graph->swaptotal_label), 0.0, 0.5);
+	gtk_table_attach (GTK_TABLE (table), mem_graph->swaptotal_label, 4, 5, 1, 2, 
+			  GTK_FILL, 0, 0, 0);	
+	
+	mem_graph->swappercent_label = gtk_label_new ("");
+	gtk_misc_set_alignment (GTK_MISC (mem_graph->swappercent_label), 1.0, 0.5);
+	gtk_table_attach (GTK_TABLE (table), mem_graph->swappercent_label, 5, 6, 1, 2, 
+			  GTK_FILL, 0, 0, 0);
+			  
+	procdata->mem_graph = mem_graph;
+	gtk_widget_show_all (vbox);
+
+	return vbox;
+}
+
+static void
+menu_item_select_cb (GtkMenuItem *proxy,
+                     ProcData *procdata)
+{
+	GtkAction *action;
+	char *message;
+
+	action = g_object_get_data (G_OBJECT (proxy),  "gtk-action");
+	g_return_if_fail (action != NULL);
+
+	g_object_get (G_OBJECT (action), "tooltip", &message, NULL);
+	if (message)
+	{
+		gtk_statusbar_push (GTK_STATUSBAR (procdata->statusbar),
+				    procdata->tip_message_cid, message);
+		g_free (message);
+	}
+}
+
+static void
+menu_item_deselect_cb (GtkMenuItem *proxy,
+                       ProcData *procdata)
+{
+	gtk_statusbar_pop (GTK_STATUSBAR (procdata->statusbar),
+			   procdata->tip_message_cid);
+}
+
+static void
+connect_proxy_cb (GtkUIManager *manager,
+                  GtkAction *action,
+                  GtkWidget *proxy,
+                  ProcData *procdata)
+{
+	if (GTK_IS_MENU_ITEM (proxy)) {
+		g_signal_connect (proxy, "select",
+				  G_CALLBACK (menu_item_select_cb), procdata);
+		g_signal_connect (proxy, "deselect",
+				  G_CALLBACK (menu_item_deselect_cb), procdata);
+	}
+}
+
+static void
+disconnect_proxy_cb (GtkUIManager *manager,
+                     GtkAction *action,
+                     GtkWidget *proxy,
+                     ProcData *procdata)
+{
+	if (GTK_IS_MENU_ITEM (proxy)) {
+		g_signal_handlers_disconnect_by_func
+			(proxy, G_CALLBACK (menu_item_select_cb), procdata);
+		g_signal_handlers_disconnect_by_func
+			(proxy, G_CALLBACK (menu_item_deselect_cb), procdata);
+	}
+}
+
 void
 create_main_window (ProcData *procdata)
 {
 	gint width, height;
 	GtkWidget *app;
+	GtkAction *action;
+	GtkWidget *menubar;
+	GtkWidget *main_box;
 	GtkWidget *notebook;
-	GtkWidget *tab_label1, *tab_label2;
+	GtkWidget *tab_label1, *tab_label2, *tab_label3;
 	GtkWidget *vbox1;
-	GtkWidget *sys_box;
-	GtkWidget *appbar1;
-	
+	GtkWidget *sys_box, *devices_box;
+
 	app = gnome_app_new ("procman", _("System Monitor"));
+
+	main_box = gtk_vbox_new (FALSE, 0);
+	gnome_app_set_contents (GNOME_APP (app), main_box);
+	gtk_widget_show (main_box);
 	
 	width = procdata->config.width;
 	height = procdata->config.height;
 	gtk_window_set_default_size (GTK_WINDOW (app), width, height);
 	gtk_window_set_resizable (GTK_WINDOW (app), TRUE);
 	
-	gnome_app_create_menus_with_data (GNOME_APP (app), menubar1_uiinfo, procdata);
-	
+	/* create the menubar */
+	procdata->uimanager = gtk_ui_manager_new ();
+
+	/* show tooltips in the statusbar */
+	g_signal_connect (procdata->uimanager, "connect_proxy",
+			  G_CALLBACK (connect_proxy_cb), procdata);
+	g_signal_connect (procdata->uimanager, "disconnect_proxy",
+			 G_CALLBACK (disconnect_proxy_cb), procdata);
+
+	gtk_window_add_accel_group (GTK_WINDOW (app),
+				    gtk_ui_manager_get_accel_group (procdata->uimanager));
+
+	if (!gtk_ui_manager_add_ui_from_string (procdata->uimanager,
+	                                        ui_info,
+	                                        -1,
+	                                        NULL)) {
+		g_error("building menus failed");
+	}
+
+	procdata->action_group = gtk_action_group_new ("ProcmanActions");
+	gtk_action_group_set_translation_domain (procdata->action_group, NULL);
+	gtk_action_group_add_actions (procdata->action_group,
+	                              menu_entries,
+	                              G_N_ELEMENTS (menu_entries),
+	                              procdata);
+	gtk_action_group_add_toggle_actions (procdata->action_group,
+	                                     toggle_menu_entries,
+	                                     G_N_ELEMENTS (toggle_menu_entries),
+	                                     procdata);
+
+	gtk_ui_manager_insert_action_group (procdata->uimanager,
+	                                    procdata->action_group,
+	                                    0);
+
+	menubar = gtk_ui_manager_get_widget (procdata->uimanager, "/MenuBar");
+	gtk_box_pack_start (GTK_BOX (main_box), menubar, FALSE, FALSE, 0);
+
+
+	/* create the main notebook */
 	notebook = gtk_notebook_new ();
-	
+  	gtk_box_pack_start (GTK_BOX (main_box), 
+	                    notebook, 
+	                    TRUE, 
+	                    TRUE, 
+	                    0);
+	gtk_widget_show (notebook);
+
 	vbox1 = create_proc_view (procdata);
+	gtk_widget_show (vbox1);
 	tab_label1 = gtk_label_new (_("Processes"));
 	gtk_widget_show (tab_label1);
 	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox1, tab_label1);
@@ -657,70 +706,46 @@ create_main_window (ProcData *procdata)
 	tab_label2 = gtk_label_new (_("Resources"));
 	gtk_widget_show (tab_label2);
 	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), sys_box, tab_label2);
-	
-	appbar1 = gtk_statusbar_new();
-	gnome_app_set_statusbar (GNOME_APP (app), appbar1);
-	
+
+	devices_box = create_disk_view (procdata);
+	gtk_widget_show(devices_box);
+	tab_label3 = gtk_label_new (_("Devices"));
+	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), devices_box, tab_label3);
+
+	g_signal_connect (G_OBJECT (notebook), "switch-page",
+			  G_CALLBACK (cb_switch_page), procdata);
+	g_signal_connect (G_OBJECT (notebook), "change-current-page",
+			  G_CALLBACK (cb_change_current_page), procdata);
+
+
+	gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), procdata->config.current_tab);
+	cb_change_current_page (GTK_NOTEBOOK (notebook), procdata->config.current_tab, procdata);
 	g_signal_connect (G_OBJECT (app), "delete_event",
                           G_CALLBACK (cb_app_delete),
                           procdata);
-	
-	gnome_app_install_menu_hints (GNOME_APP (app), menubar1_uiinfo);
-		    
-	g_signal_connect (G_OBJECT (notebook), "switch-page",
-			    G_CALLBACK (cb_switch_page), procdata);
 
-	if (procdata->config.current_tab == 0)
-		procdata->timeout = gtk_timeout_add (procdata->config.update_interval,
-			 		     cb_timeout, procdata);
-	else {
-		load_graph_start (procdata->cpu_graph);
-		load_graph_start (procdata->mem_graph);
-	}
-	 	
-	gtk_widget_show (vbox1);
-	gnome_app_set_contents (GNOME_APP (app), notebook);
-	gtk_widget_show (notebook);
 
-	update_sensitivity (procdata, FALSE);
-	
-	/* We cheat and force it to set up the labels */
- 	procdata->config.show_more_info = !procdata->config.show_more_info;
- 	toggle_infoview (procdata);
+	/* create the statusbar */
+	procdata->statusbar = gtk_statusbar_new();
+	gnome_app_set_statusbar (GNOME_APP (app), procdata->statusbar);
+	procdata->tip_message_cid = gtk_statusbar_get_context_id
+		(GTK_STATUSBAR (procdata->statusbar), "tip_message");
+
+
+	action = gtk_action_group_get_action (procdata->action_group, "ShowDependencies");
+	gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action),
+				      procdata->config.show_tree);
+
+	action = gtk_action_group_get_action (procdata->action_group, "ShowThreads");
+	gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action),
+				      procdata->config.show_threads);
+
 
- 	gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), procdata->config.current_tab);
- 	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (view1_menu_uiinfo[0].widget),
-							  procdata->config.show_tree);
- 	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (view1_menu_uiinfo[1].widget),
-							  procdata->config.show_threads);
-	
 	procdata->app = app;
-
-}
-
-
-void
-toggle_infoview (ProcData *procdata)
-{
-	if (procdata->config.show_more_info)
-	{
-		gtk_widget_hide (procdata->infobox);
-		gtk_label_set_text_with_mnemonic (GTK_LABEL (infolabel),
-						  _("More _Info >>"));
-	}
-	else
-	{
-		infoview_update (procdata);
-		gtk_widget_show_all (procdata->infobox);
-		gtk_label_set_text_with_mnemonic (GTK_LABEL (infolabel),
-						  _("<< Less _Info"));
-	}
-
-	procdata->config.show_more_info = ! procdata->config.show_more_info;
 }
 
 void
-do_popup_menu (ProcData *data, GdkEventButton *event)
+do_popup_menu (ProcData *procdata, GdkEventButton *event)
 {
 	gint button;
 	gint event_time;
@@ -734,60 +759,63 @@ do_popup_menu (ProcData *data, GdkEventButton *event)
 		event_time = gtk_get_current_event_time ();
 	}
 
-	gtk_menu_popup (GTK_MENU (popup_menu), NULL, NULL,
+	gtk_menu_popup (GTK_MENU (procdata->popup_menu), NULL, NULL,
 			NULL, NULL, button, event_time);
 }
 
 void
 update_sensitivity (ProcData *data, gboolean sensitivity)
 {
-	gtk_widget_set_sensitive (endprocessbutton, sensitivity);
-	
-	gtk_widget_set_sensitive (data->infobox, sensitivity);
-	/*Edit->End Process*/
-	gtk_widget_set_sensitive (edit1_menu_uiinfo[0].widget, sensitivity);
-	/*Edit->Kill Process*/
-	gtk_widget_set_sensitive (edit1_menu_uiinfo[1].widget, sensitivity);
-	/*Edit->Change Priority*/
-	gtk_widget_set_sensitive (edit1_menu_uiinfo[3].widget, sensitivity);
-	/*View->Hide Process*/
-	gtk_widget_set_sensitive (view1_menu_uiinfo[3].widget, sensitivity);
-	/*View->Hidden Processes*/
-	gtk_widget_set_sensitive (view1_menu_uiinfo[4].widget, sensitivity);
-	/*View->Memory Maps*/
-	gtk_widget_set_sensitive (view1_menu_uiinfo[6].widget, sensitivity);
-	/*View->Open Files*/
-	gtk_widget_set_sensitive (view1_menu_uiinfo[7].widget, sensitivity);	
+	GtkAction *action;
+
+	if(data->endprocessbutton) {
+		/* avoid error on startup if endprocessbutton
+		   has not been built yet */
+		gtk_widget_set_sensitive (data->endprocessbutton, sensitivity);
+	}
+
+	gtk_widget_set_sensitive (data->infoview.box, sensitivity);
+
+	action = gtk_action_group_get_action (data->action_group, "EndProcess");
+	gtk_action_set_sensitive (action, sensitivity);
+	action = gtk_action_group_get_action (data->action_group, "KillProcess");
+	gtk_action_set_sensitive (action, sensitivity);
+	action = gtk_action_group_get_action (data->action_group, "ChangePriority");
+	gtk_action_set_sensitive (action, sensitivity);
+	action = gtk_action_group_get_action (data->action_group, "HideProcess");
+	gtk_action_set_sensitive (action, sensitivity);
+	action = gtk_action_group_get_action (data->action_group, "HiddenProcesses");
+	gtk_action_set_sensitive (action, sensitivity);
+	action = gtk_action_group_get_action (data->action_group, "MemoryMaps");
+	gtk_action_set_sensitive (action, sensitivity);
+	action = gtk_action_group_get_action (data->action_group, "OpenFiles");
+	gtk_action_set_sensitive (action, sensitivity);
 }
 
 static void		
-cb_toggle_tree (GtkMenuItem *menuitem, gpointer data)
+cb_toggle_tree (GtkAction *action, gpointer data)
 {
 	ProcData *procdata = data;
-	GtkCheckMenuItem *menu = GTK_CHECK_MENU_ITEM (view1_menu_uiinfo[0].widget);
 	GConfClient *client = procdata->client;
 	gboolean show;
-	
-	show = gtk_check_menu_item_get_active (menu);
+
+	show = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
 	if (show == procdata->config.show_tree)
 		return;
-		
+
 	gconf_client_set_bool (client, "/apps/procman/show_tree", show, NULL);
-	
 }
 
 static void		
-cb_toggle_threads (GtkMenuItem *menuitem, gpointer data)
+cb_toggle_threads (GtkAction *action, gpointer data)
 {
 	ProcData *procdata = data;
-	GtkCheckMenuItem *menu = GTK_CHECK_MENU_ITEM (view1_menu_uiinfo[1].widget);
 	GConfClient *client = procdata->client;
 	gboolean show;
-	
-	show = gtk_check_menu_item_get_active (menu);
+
+	show = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
 	if (show == procdata->config.show_threads)
 		return;
-		
+
 	gconf_client_set_bool (client, "/apps/procman/show_threads", show, NULL);
-	
 }
