@@ -17,9 +17,10 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-#  include <config.h>
-#endif
+
+#include <config.h>
+
+#include <glib/gi18n.h>
 
 #include <signal.h>
 #include <string.h>
@@ -114,18 +115,18 @@ procdialog_create_kill_dialog (ProcData *data, int signal)
                 /*translators: primary alert message*/
   		primary = _("Kill the selected process?");
 		/*translators: secondary alert message*/
-		secondary = _("Killing a process, you could destroy your data, "
-			      "break the working session or create a security risk. "
-			      "Only misbehaving processes should be killed.");
+		secondary = _("Killing a process may destroy data, break the "
+			      "session or introduce a security risk. "
+			      "Only unresponding processes should be killed.");
   		button_text = _("_Kill Process");
 		  	}
   	else {
                 /*translators: primary alert message*/
                 primary = _("End the selected process?");
 	        /*translators: secondary alert message*/
-                secondary = _("Ending a process, you could destroy your data, "
-		              "break the working session or create a security risk. "
-			      "Only misbehaving processes should be ended.");
+		secondary = _("Ending a process may destroy data, break the "
+			      "session or introduce a security risk. "
+			      "Only unresponding processes should be ended.");
                 button_text = _("_End Process");
   	}
 
@@ -316,6 +317,21 @@ show_kill_dialog_toggled (GtkToggleButton *button, gpointer data)
 		
 }
 
+
+static void
+show_all_fs_toggled (GtkToggleButton *button, gpointer data)
+{
+	ProcData *procdata = data;
+	GConfClient *client = procdata->client;
+
+	gboolean toggled;
+
+	toggled = gtk_toggle_button_get_active (button);
+
+	gconf_client_set_bool (client, "/apps/procman/show_all_fs", toggled, NULL);
+}
+
+
 static void
 show_hide_dialog_toggled (GtkToggleButton *button, gpointer data)
 {
@@ -508,6 +524,7 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 	GtkSizeGroup *size;
 	gfloat update;
 	gchar *tmp;
+	GdkColor color;
 	
 	if (prefs_dialog)
 		return;
@@ -679,14 +696,14 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 	gtk_box_pack_start (GTK_BOX (hbox2), label, FALSE, FALSE, 0);
 	gtk_size_group_add_widget (size, label);
 	
-	color_picker = gnome_color_picker_new ();
-	gnome_color_picker_set_i16 (GNOME_COLOR_PICKER (color_picker), 
-				    procdata->config.bg_color.red,
-				    procdata->config.bg_color.green,
-				    procdata->config.bg_color.blue, 0);
+	color.red   = procdata->config.bg_color.red;
+	color.green = procdata->config.bg_color.green;
+   	color.blue  = procdata->config.bg_color.blue;
+	color_picker = gtk_color_button_new_with_color (&color);
+
 	g_signal_connect (G_OBJECT (color_picker), "color_set",
 			          G_CALLBACK (cb_bg_color_changed), procdata);
-	gtk_box_pack_start (GTK_BOX (hbox2), color_picker,TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (hbox2), color_picker, FALSE, FALSE, 0);
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), color_picker);
 	gtk_widget_show (color_picker);
 		
@@ -698,26 +715,33 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 	gtk_box_pack_start (GTK_BOX (hbox2), label, FALSE, FALSE, 0);
 	gtk_size_group_add_widget (size, label);
 	
-	color_picker = gnome_color_picker_new ();
-	gnome_color_picker_set_i16 (GNOME_COLOR_PICKER (color_picker), 
-				    procdata->config.frame_color.red,
-				    procdata->config.frame_color.green,
-				    procdata->config.frame_color.blue, 0);
+	color.red   = procdata->config.frame_color.red;
+	color.green = procdata->config.frame_color.green;
+   	color.blue  = procdata->config.frame_color.blue;
+	color_picker = gtk_color_button_new_with_color (&color);
+	
 	g_signal_connect (G_OBJECT (color_picker), "color_set",
 			    G_CALLBACK (cb_frame_color_changed), procdata);	  
-	gtk_box_pack_start (GTK_BOX (hbox2), color_picker, TRUE, TRUE, 0);	
+	gtk_box_pack_start (GTK_BOX (hbox2), color_picker, FALSE, FALSE, 0);
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), color_picker);
 	gtk_widget_show (color_picker);
-	
+
+
+	/*
+	 * Devices
+	 */
 	vbox = gtk_vbox_new (FALSE, 6);
-	gtk_box_pack_start (GTK_BOX (sys_box), vbox, FALSE, FALSE, 0);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
+	tab_label = gtk_label_new (_("Devices"));
+	gtk_widget_show (tab_label);
+	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox, tab_label);
 	
 	tmp = g_strdup_printf ("<b>%s</b>", _("Devices"));
 	label = gtk_label_new (NULL);
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_label_set_markup (GTK_LABEL (label), tmp);
 	g_free (tmp);
-	gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
 	
 	hbox = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
@@ -751,7 +775,19 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 	label = gtk_label_new_with_mnemonic (_("seconds"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_box_pack_start (GTK_BOX (hbox3), label, FALSE, FALSE, 0);
-	
+
+
+	hbox2 = gtk_hbox_new (FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (vbox2), hbox2, FALSE, FALSE, 0);
+	check_button = gtk_check_button_new_with_mnemonic (_("Show _all filesystems"));
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check_button),
+				      procdata->config.show_all_fs);
+	g_signal_connect (G_OBJECT (check_button), "toggled",
+			    G_CALLBACK (show_all_fs_toggled), procdata);
+	gtk_box_pack_start (GTK_BOX (hbox2), check_button, FALSE, FALSE, 0);
+
+
+
 	gtk_widget_show_all (dialog);
 	g_signal_connect (G_OBJECT (dialog), "response",
 				  G_CALLBACK (prefs_dialog_button_pressed), procdata);
@@ -763,43 +799,66 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 }
 
 
+
+typedef gboolean (*GnomesuExecFunc) (char *commandline);
+
+
+static GnomesuExecFunc G_GNUC_CONST
+procman_get_gnomesu_exec(void)
+{
+	static gboolean is_init = FALSE;
+	static gpointer gnomesu_exec = NULL;
+
+	if(!is_init) {
+		GModule *libgnomesu;
+
+		libgnomesu = g_module_open ("libgnomesu.so.0",
+					    G_MODULE_BIND_LAZY | G_MODULE_BIND_LOCAL);
+
+		if(libgnomesu) {
+			if(g_module_symbol (libgnomesu, "gnomesu_exec", &gnomesu_exec)) {
+				g_module_make_resident(libgnomesu);
+			}
+			else {
+				g_warning("Cannot found gnomesu_exec : %s", g_module_error());
+				g_module_close(libgnomesu);
+			}
+		}
+
+		is_init = TRUE;
+	}
+
+	return (GnomesuExecFunc)gnomesu_exec;
+}
+
+
+
 /*
 ** type determines whether if dialog is for killing process (type=0) or renice (type=other).
 ** extra_value is not used for killing and is priority for renice
 */
-void procdialog_create_root_password_dialog (gint type, ProcData *procdata, gint pid, 
-					     gint extra_value, gchar *text)
+gboolean
+procdialog_create_root_password_dialog (gint type, ProcData *procdata, gint pid,
+					gint extra_value)
 {
-	GModule *mod;
-	gpointer gnomesu_exec;
-	gboolean has_libgnomesu = FALSE;
-	typedef gboolean (*GnomesuExecFunc) (char *commandline);
+	GnomesuExecFunc gnomesu_exec;
 
-	/* Attempt to use libgnomesu */
-	mod = g_module_open ("libgnomesu.so.0", G_MODULE_BIND_LAZY | G_MODULE_BIND_LOCAL);
-	if (mod) {
-		if (g_module_symbol (mod, "gnomesu_exec", &gnomesu_exec)) {
-			gchar *command;
+	gnomesu_exec = procman_get_gnomesu_exec ();
 
-			has_libgnomesu = TRUE;
-			if (type == 0)
-				command = g_strdup_printf ("kill -s %d %d", extra_value, pid);
-			else
-				command = g_strdup_printf ("renice %d %d", extra_value, pid);
-			((GnomesuExecFunc) gnomesu_exec) (command);
-			g_free (command);
-		}
+	if(gnomesu_exec)
+	{
+		gchar command[80];
 
-		g_module_close (mod);
-	}
-
-	if (!has_libgnomesu) {
 		if (type == 0)
-			g_warning(_("Cannot kill process with pid %d with signal %d"),
-				  pid, extra_value);
+			g_snprintf (command, sizeof command,
+				    "kill -s %d %d", extra_value, pid);
 		else
-			g_warning(_("Cannot change the priority of process with pid %d to %d"),
-				  pid, extra_value);
+			g_snprintf (command, sizeof command,
+				    "renice %d %d", extra_value, pid);
+
+		return gnomesu_exec (command);
 	}
+
+	return FALSE;
 }
 
