@@ -20,18 +20,17 @@
 #define _PROCDIALOGS_H_
 
 
-#include <gnome.h>
-#include <procman.h>
+#include <glib.h>
+#include "procman.h"
 
-extern int kill_signal;
+extern int kill_signal G_GNUC_INTERNAL;
 
 void			procdialog_create_hide_dialog (ProcData *data) G_GNUC_INTERNAL;
 void			procdialog_create_kill_dialog (ProcData *data, int signal) G_GNUC_INTERNAL;
 void 			procdialog_create_renice_dialog (ProcData *data) G_GNUC_INTERNAL;
-void			procdialog_create_root_password_dialog (gint type, 
+gboolean		procdialog_create_root_password_dialog (gint type,
 								ProcData *procdata,
-								gint pid, gint extra_value,
-								gchar *text) G_GNUC_INTERNAL;
+								gint pid, gint extra_value) G_GNUC_INTERNAL;
 void 			procdialog_create_memmaps_dialog (ProcData *data) G_GNUC_INTERNAL;
 void			procdialog_create_preferences_dialog (ProcData *data) G_GNUC_INTERNAL;
 
