@@ -19,12 +19,19 @@
 
 #include <config.h>
 
+#include <stdlib.h>
+
+#include <glib.h>
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
+#include <gdk/gdkx.h>
 #include <gnome.h>
-#include <libgnomeui/gnome-window-icon.h>
+#include <bacon-message-connection.h>
 #include <libgnomevfs/gnome-vfs.h>
 #include <gconf/gconf-client.h>
 #include <glibtop.h>
 #include <glibtop/close.h>
+#include <glibtop/loadavg.h>
 #include "load-graph.h"
 #include "procman.h"
 #include "interface.h"
@@ -32,6 +39,7 @@
 #include "prettytable.h"
 #include "favorites.h"
 #include "callbacks.h"
+#include "smooth_refresh.h"
 
 
 static void
@@ -78,7 +86,7 @@ warning_changed_cb (GConfClient *client, guint id, GConfEntry *entry, gpointer d
 	const gchar *key = gconf_entry_get_key (entry);
 	GConfValue *value = gconf_entry_get_value (entry);
 	
-	if (!g_strcasecmp (key, "/apps/procman/kill_dialog")) {
+	if (g_str_equal (key, "/apps/procman/kill_dialog")) {
 		procdata->config.show_kill_warning = gconf_value_get_bool (value);
 	}
 	else {
@@ -93,15 +101,18 @@ timeouts_changed_cb (GConfClient *client, guint id, GConfEntry *entry, gpointer
 	const gchar *key = gconf_entry_get_key (entry);
 	GConfValue *value = gconf_entry_get_value (entry);
 
-	if (!g_strcasecmp (key, "/apps/procman/update_interval")) {
+	if (g_str_equal (key, "/apps/procman/update_interval")) {
 		procdata->config.update_interval = gconf_value_get_int (value);
 		procdata->config.update_interval = 
 			MAX (procdata->config.update_interval, 1000);
+
+		smooth_refresh_reset(procdata->smooth_refresh);
+
 		gtk_timeout_remove (procdata->timeout);
 		procdata->timeout = gtk_timeout_add (procdata->config.update_interval, 
 						     cb_timeout, procdata);
 	}
-	else if (!g_strcasecmp (key, "/apps/procman/graph_update_interval")){
+	else if (g_str_equal (key, "/apps/procman/graph_update_interval")){
 		procdata->config.graph_update_interval = gconf_value_get_int (value);
 		procdata->config.graph_update_interval = 
 			MAX (procdata->config.graph_update_interval, 
@@ -139,17 +150,17 @@ color_changed_cb (GConfClient *client, guint id, GConfEntry *entry, gpointer dat
 	GConfValue *value = gconf_entry_get_value (entry);
 	const gchar *color = gconf_value_get_string (value);
 
-	if (!g_strcasecmp (key, "/apps/procman/bg_color")) {
+	if (g_str_equal (key, "/apps/procman/bg_color")) {
 		gdk_color_parse (color, &procdata->config.bg_color);
 		procdata->cpu_graph->colors[0] = procdata->config.bg_color;
 		procdata->mem_graph->colors[0] = procdata->config.bg_color;
 	}
-	else if (!g_strcasecmp (key, "/apps/procman/frame_color")) {
+	else if (g_str_equal (key, "/apps/procman/frame_color")) {
 		gdk_color_parse (color, &procdata->config.frame_color);
 		procdata->cpu_graph->colors[1] = procdata->config.frame_color;
 		procdata->mem_graph->colors[1] = procdata->config.frame_color;
 	}
-	else if (!g_strcasecmp (key, "/apps/procman/cpu_color")) {
+	else if (g_str_equal (key, "/apps/procman/cpu_color")) {
 		gdk_color_parse (color, &procdata->config.cpu_color[0]);
 		procdata->cpu_graph->colors[2] = procdata->config.cpu_color[0];
 	}
@@ -159,18 +170,18 @@ color_changed_cb (GConfClient *client, guint id, GConfEntry *entry, gpointer dat
 		for (i=1;i<GLIBTOP_NCPU;i++) {
 			gchar *cpu_key;
 			cpu_key = g_strdup_printf ("/apps/procman/cpu_color%d",i);
-			if (!g_strcasecmp (key, cpu_key)) {
+			if (g_str_equal (key, cpu_key)) {
 				gdk_color_parse (color, &procdata->config.cpu_color[i]);
 				procdata->cpu_graph->colors[i+2] = procdata->config.cpu_color[i];
 			}
 			g_free (cpu_key);
 		}
 	}
-	else if (!g_strcasecmp (key, "/apps/procman/mem_color")) {
+	else if (g_str_equal (key, "/apps/procman/mem_color")) {
 		gdk_color_parse (color, &procdata->config.mem_color);
 		procdata->mem_graph->colors[2] = procdata->config.mem_color;
 	}
-	else if (!g_strcasecmp (key, "/apps/procman/swap_color")) {
+	else if (g_str_equal (key, "/apps/procman/swap_color")) {
 		gdk_color_parse (color, &procdata->config.swap_color);
 		procdata->mem_graph->colors[3] = procdata->config.swap_color;
 	}
@@ -180,6 +191,20 @@ color_changed_cb (GConfClient *client, guint id, GConfEntry *entry, gpointer dat
 		
 }
 
+
+
+static void
+show_all_fs_changed_cb (GConfClient *client, guint id, GConfEntry *entry, gpointer data)
+{
+	ProcData * const procdata = data;
+	GConfValue *value = gconf_entry_get_value (entry);
+
+	procdata->config.show_all_fs = gconf_value_get_bool (value);
+
+	cb_update_disks (data);
+}
+
+
 static ProcData *
 procman_data_new (GConfClient *client)
 {
@@ -189,11 +214,12 @@ procman_data_new (GConfClient *client)
 	gint swidth, sheight;
 	gint i;
 	glibtop_cpu cpu;
-	
+	glibtop_loadavg loadavg;
+	gsize nprocs;
+
 	pd = g_new0 (ProcData, 1);
 	
 	pd->tree = NULL;
-	pd->infobox = NULL;
 	pd->info = NULL;
 	pd->pids = g_hash_table_new(g_direct_hash, g_direct_equal);
 	pd->selected_process = NULL;
@@ -203,6 +229,16 @@ procman_data_new (GConfClient *client)
 	pd->mem_graph = NULL;
 	pd->disk_timeout = -1;
 
+	glibtop_get_loadavg(&loadavg);
+	nprocs = (loadavg.nr_tasks ? 1.2f * loadavg.nr_tasks : 100);
+	pd->procinfo_allocator = g_mem_chunk_create(ProcInfo, nprocs, G_ALLOC_AND_FREE);
+
+	/* username is usually 8 chars long
+	   for caching, we create chunks of 128 chars */
+	pd->users = g_string_chunk_new(128);
+	/* push empty string */
+	g_string_chunk_insert_const(pd->users, "");
+
 	pd->config.width = gconf_client_get_int (client, "/apps/procman/width", NULL);
 	pd->config.height = gconf_client_get_int (client, "/apps/procman/height", NULL);
 	pd->config.show_more_info = gconf_client_get_bool (client, "/apps/procman/more_info", NULL);
@@ -234,11 +270,21 @@ procman_data_new (GConfClient *client)
 								 NULL);
 	gconf_client_notify_add (client, "/apps/procman/disks_interval", timeouts_changed_cb,
 				 pd, NULL, NULL);
+
+
+	/* /apps/procman/show_all_fs */
+	pd->config.show_all_fs = gconf_client_get_bool (
+		client, "/apps/procman/show_all_fs",
+		NULL);
+	gconf_client_notify_add
+		(client, "/apps/procman/show_all_fs",
+		 show_all_fs_changed_cb, pd, NULL, NULL);
+
+
 	pd->config.whose_process = gconf_client_get_int (client, "/apps/procman/view_as", NULL);
 	gconf_client_notify_add (client, "/apps/procman/view_as", view_as_changed_cb,
 				 pd, NULL, NULL);
 	pd->config.current_tab = gconf_client_get_int (client, "/apps/procman/current_tab", NULL);
-	pd->config.pane_pos = gconf_client_get_int (client, "/apps/procman/pane_pos", NULL);
 
 	color = gconf_client_get_string (client, "/apps/procman/bg_color", NULL);
 	if (!color)
@@ -305,13 +351,12 @@ procman_data_new (GConfClient *client)
 	pd->config.graph_update_interval = MAX (pd->config.graph_update_interval, 250);
 	pd->config.disks_update_interval = MAX (pd->config.disks_update_interval, 1000);
 	pd->config.whose_process = CLAMP (pd->config.whose_process, 0, 2);
-	pd->config.current_tab = CLAMP (pd->config.current_tab, 0, 1);
-	if (pd->config.pane_pos == 0)
-		pd->config.pane_pos = 300;
+	pd->config.current_tab = CLAMP (pd->config.current_tab, 0, 2);
 	
 	/* Determinie number of cpus since libgtop doesn't really tell you*/
 	pd->config.num_cpus = 0;
 	glibtop_get_cpu (&cpu);
+	pd->frequency = cpu.frequency;
 	i=0;
     	while (i < GLIBTOP_NCPU && cpu.xcpu_total[i] != 0) {
     	    pd->config.num_cpus ++;
@@ -319,7 +364,9 @@ procman_data_new (GConfClient *client)
     	}
     	if (pd->config.num_cpus == 0)
     		pd->config.num_cpus = 1;
-    	
+
+	pd->smooth_refresh = smooth_refresh_new(&pd->config.update_interval);
+
 	return pd;
 
 }
@@ -330,22 +377,21 @@ procman_free_data (ProcData *procdata)
 
 	proctable_free_table (procdata);
 	g_hash_table_destroy(procdata->pids);
-	/* pretty_table_free (procdata->pretty_table); */
-	
+	pretty_table_free (procdata->pretty_table);
+	smooth_refresh_destroy(procdata->smooth_refresh);
 	g_free (procdata);
 	
 }
 
 
 gboolean
-procman_get_tree_state (GConfClient *client, GtkWidget *tree, gchar *prefix)
+procman_get_tree_state (GConfClient *client, GtkWidget *tree, const gchar *prefix)
 {
 	GtkTreeModel *model;
 	gint sort_col;
 	GtkSortType order;
 	gchar *key;
-	gint i = 0;
-	gboolean done = FALSE;
+	gint i;
 	
 	g_return_val_if_fail (tree, FALSE);
 	g_return_val_if_fail (prefix, FALSE);
@@ -368,7 +414,7 @@ procman_get_tree_state (GConfClient *client, GtkWidget *tree, gchar *prefix)
 					      	      sort_col,
 					              order);
 	
-	while (!done) {
+	for(i = 0; i < NUM_COLUMNS; ++i) {
 		GtkTreeViewColumn *column;
 		GConfValue *value = NULL;
 		gint width;
@@ -388,21 +434,18 @@ procman_get_tree_state (GConfClient *client, GtkWidget *tree, gchar *prefix)
 			g_free (key);
 		
 			column = gtk_tree_view_get_column (GTK_TREE_VIEW (tree), i);
+			if(!column) continue;
 			gtk_tree_view_column_set_visible (column, visible);
 			if (width > 0)
 				gtk_tree_view_column_set_fixed_width (column, width);
 		}
-		else
-			done = TRUE;
-		
-		i++;
 	}
 	
 	return TRUE;
 }
 
 void
-procman_save_tree_state (GConfClient *client, GtkWidget *tree, gchar *prefix)
+procman_save_tree_state (GConfClient *client, GtkWidget *tree, const gchar *prefix)
 {
 	GtkTreeModel *model;
 	GList *columns;
@@ -456,7 +499,7 @@ void
 procman_save_config (ProcData *data)
 {
 	GConfClient *client = data->client;
-	gint width, height, pane_pos;
+	gint width, height;
 
 	g_return_if_fail(data != NULL);
 		
@@ -467,14 +510,10 @@ procman_save_config (ProcData *data)
 	data->config.width = width;
 	data->config.height = height;
 	
-	pane_pos = get_sys_pane_pos ();
-	data->config.pane_pos = pane_pos;
-	
 	gconf_client_set_int (client, "/apps/procman/width", data->config.width, NULL);
 	gconf_client_set_int (client, "/apps/procman/height", data->config.height, NULL);	
 	gconf_client_set_bool (client, "/apps/procman/more_info", data->config.show_more_info, NULL);
 	gconf_client_set_int (client, "/apps/procman/current_tab", data->config.current_tab, NULL);
-	gconf_client_set_int (client, "/apps/procman/pane_pos", data->config.pane_pos, NULL);
 	
 	save_blacklist (data, client);
 
@@ -485,21 +524,93 @@ procman_save_config (ProcData *data)
 }
 
 
+static void
+cb_server (const gchar *msg, gpointer user_data)
+{
+	GdkWindow *window;
+	ProcData *procdata;
+	guint32 timestamp;
+
+	window = gdk_get_default_root_window ();
+
+	procdata = *(ProcData**)user_data;
+	g_assert (procdata != NULL);
+
+	timestamp = strtoul(msg, NULL, 0);
+
+	if(timestamp)
+	{
+		gdk_x11_window_set_user_time (window, timestamp);
+	}
+	else
+	{
+		g_warning ("Couldn't get timestamp");
+	}
+
+	gtk_window_present (GTK_WINDOW(procdata->app));
+}
+
+
+static void
+init_volume_monitor(ProcData *procdata)
+{
+	GnomeVFSVolumeMonitor *mon;
+	mon = gnome_vfs_get_volume_monitor();
+
+	g_signal_connect(mon, "volume_mounted",
+			 G_CALLBACK(cb_volume_mounted_or_unmounted), procdata);
+
+	g_signal_connect(mon, "volume_unmounted",
+			 G_CALLBACK(cb_volume_mounted_or_unmounted), procdata);
+}
+
+
 int
 main (int argc, char *argv[])
 {
 	GnomeProgram *procman;
 	GConfClient *client;
 	ProcData *procdata;
-	
+	BaconMessageConnection *conn;
+
+	conn = bacon_message_connection_new ("gnome-system-monitor");
+	if (!conn) g_error("Couldn't connect to gnome-system-monitor");
+
+	if (bacon_message_connection_get_is_server (conn))
+	{
+		bacon_message_connection_set_callback (conn, cb_server, &procdata);
+	}
+	else /* client */
+	{
+		const char *desktop_startup_id, *timestamp;
+
+		timestamp = NULL;
+		desktop_startup_id = g_getenv("DESKTOP_STARTUP_ID");
+
+		if(desktop_startup_id)
+		{
+			timestamp = strstr(desktop_startup_id, "_TIME");
+		}
+
+		if(!timestamp)
+		{
+			g_warning ("Couldn't get $DESKTOP_STARTUP_ID");
+			timestamp = "0";
+		}
+
+		bacon_message_connection_send (conn, timestamp);
+		bacon_message_connection_free (conn);
+		return 1;
+	}
+
 	bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
 	procman = gnome_program_init ("gnome-system-monitor", VERSION, 
-				      LIBGNOMEUI_MODULE, argc, argv,
+				       LIBGNOMEUI_MODULE, argc, argv,
 				      GNOME_PARAM_APP_DATADIR,DATADIR, NULL);
-	gtk_window_set_default_icon_name ("procman");
+	gtk_window_set_default_icon_name ("gnome-monitor");
 		    
 	gconf_init (argc, argv, NULL);
 			    
@@ -516,10 +627,12 @@ main (int argc, char *argv[])
 	create_main_window (procdata);
 	
 	proctable_update_all (procdata);
-		 
+
+	init_volume_monitor (procdata);
+
 	g_return_val_if_fail(procdata->app != NULL, 1);
 			
- 	gtk_widget_show (procdata->app);
+ 	gtk_widget_show(procdata->app);
  	
 	gtk_main ();
 	
