@@ -17,12 +17,15 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-#  include <config.h>
-#endif
+
+#include <config.h>
+
 
 #include <string.h>
+#include <math.h>
+#include <glib/gi18n.h>
 #include <glibtop.h>
+#include <glibtop/loadavg.h>
 #include <glibtop/proclist.h>
 #include <glibtop/procstate.h>
 #include <glibtop/procmem.h>
@@ -87,6 +90,9 @@ sort_ints (GtkTreeModel *model, GtkTreeIter *itera, GtkTreeIter *iterb, gpointer
 	case COL_MEMXSERVER:
 		return PROCMAN_CMP(infoa->memxserver, infob->memxserver);
 
+	case COL_CPU_TIME:
+		return PROCMAN_CMP(infoa->cpu_time_last, infob->cpu_time_last);
+
 	default:
 		g_assert_not_reached();
 		return 0;
@@ -149,6 +155,33 @@ set_proctree_reorderable(ProcData *procdata)
 }
 
 
+
+static gboolean
+search_equal_func(GtkTreeModel *model,
+		  gint column,
+		  const gchar *key,
+		  GtkTreeIter *iter,
+		  gpointer search_data)
+{
+	char* name;
+	char* user;
+
+	gtk_tree_model_get(model, iter,
+			   COL_NAME, &name,
+			   COL_USER, &user,
+			   -1);
+
+	if(name && strstr(name, key))
+		return FALSE;
+
+	if(user && strstr(user, key))
+		return FALSE;
+
+	return TRUE;
+}
+
+
+
 GtkWidget *
 proctable_new (ProcData * const procdata)
 {
@@ -170,6 +203,7 @@ proctable_new (ProcData * const procdata)
 		N_("RSS Memory"),
 		N_("X Server Memory"),
 		/* xgettext:no-c-format */ N_("% CPU"),
+		N_("CPU time"),
 		N_("Nice"),
 		N_("ID"),
 		N_("Security Context"),
@@ -198,6 +232,7 @@ proctable_new (ProcData * const procdata)
 				    G_TYPE_STRING,	/* RSS Memory	*/
 				    G_TYPE_STRING,	/* X Server Memory */
 				    G_TYPE_UINT,	/* % CPU	*/
+				    G_TYPE_STRING,	/* CPU time	*/
 				    G_TYPE_INT,		/* Nice		*/
 				    G_TYPE_UINT,	/* ID		*/
 				    G_TYPE_STRING,	/* Security Context */
@@ -207,6 +242,10 @@ proctable_new (ProcData * const procdata)
 		);
 
 	proctree = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
+	gtk_tree_view_set_search_equal_func (GTK_TREE_VIEW (proctree),
+					     search_equal_func,
+					     NULL,
+					     NULL);
 	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (proctree), TRUE);
 	g_object_unref (G_OBJECT (model));
 
@@ -248,6 +287,7 @@ proctable_new (ProcData * const procdata)
 		case COL_CPU:
 		case COL_NICE:
 		case COL_PID:
+		case COL_CPU_TIME:
 			g_object_set(G_OBJECT(cell_renderer),
 				     "xalign", 1.0f,
 				     NULL);
@@ -267,36 +307,26 @@ proctable_new (ProcData * const procdata)
 
 	gtk_container_add (GTK_CONTAINER (scrolled), proctree);
 
-	gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (model),
-					 COL_MEM,
-					 sort_ints,
-					 GINT_TO_POINTER (COL_MEM),
-					 NULL);
-	gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (model),
-					 COL_VMSIZE,
-					 sort_ints,
-					 GINT_TO_POINTER (COL_VMSIZE),
-					 NULL);
-	gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (model),
-					 COL_MEMRES,
-					 sort_ints,
-					 GINT_TO_POINTER (COL_MEMRES),
-					 NULL);
-	gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (model),
-					 COL_MEMSHARED,
-					 sort_ints,
-					 GINT_TO_POINTER (COL_MEMSHARED),
-					 NULL);
-	gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (model),
-					 COL_MEMRSS,
-					 sort_ints,
-					 GINT_TO_POINTER (COL_MEMRSS),
-					 NULL);
-	gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (model),
-					 COL_MEMXSERVER,
-					 sort_ints,
-					 GINT_TO_POINTER (COL_MEMXSERVER),
-					 NULL);
+
+	for(i = 0; i< NUM_COLUMNS - 2; i++)
+	{
+		switch(i)
+		{
+		case COL_MEM:
+		case COL_VMSIZE:
+		case COL_MEMRES:
+		case COL_MEMSHARED:
+		case COL_MEMRSS:
+		case COL_MEMXSERVER:
+		case COL_CPU_TIME:
+			gtk_tree_sortable_set_sort_func (
+				GTK_TREE_SORTABLE (model),
+				i,
+				sort_ints,
+				GINT_TO_POINTER(i),
+				NULL);
+		}
+	}
 
 	procdata->tree = proctree;
 
@@ -314,8 +344,6 @@ proctable_new (ProcData * const procdata)
 	g_signal_connect (G_OBJECT (gtk_tree_view_get_selection (GTK_TREE_VIEW (proctree))),
 			  "changed",
 			  G_CALLBACK (cb_row_selected), procdata);
-	g_signal_connect (G_OBJECT (proctree), "row_activated",
-			  G_CALLBACK (cb_tree_row_activated), procdata);
 	g_signal_connect (G_OBJECT (proctree), "popup_menu",
 			  G_CALLBACK (cb_tree_popup_menu), procdata);
 	g_signal_connect (G_OBJECT (proctree), "button_press_event",
@@ -326,16 +354,15 @@ proctable_new (ProcData * const procdata)
 
 
 static void
-proctable_free_info (ProcInfo *info)
+proctable_free_info (ProcData *procdata, ProcInfo *info)
 {
 	g_return_if_fail(info != NULL);
 
 	g_free (info->name);
 	g_free (info->arguments);
-	g_free (info->user);
 	g_free (info->security_context);
 	g_list_free (info->children);
-	g_free (info);
+	g_mem_chunk_free (procdata->procinfo_allocator, info);
 }
 
 
@@ -377,17 +404,51 @@ static void
 get_process_name (ProcInfo *info,
 		  const gchar *cmd, const gchar *args)
 {
-
-	/* strip the absolute path from the arguments
-	 * if args is not null nor ""
-	 */
 	if (args && *args)
-		info->name = g_path_get_basename (args);
-	else
-		info->name = g_strdup (cmd);
+	{
+		char* basename;
+		basename = g_path_get_basename (args);
+
+		if(g_str_has_prefix (basename, cmd))
+		{
+			info->name = basename;
+			return;
+		}
+
+		g_free (basename);
+	}
+
+	info->name = g_strdup (cmd);
 }
 
 
+
+static void
+get_process_user(ProcData* procdata, ProcInfo* info, uid_t uid)
+{
+	struct passwd* pwd;
+	char* username;
+
+	if(G_LIKELY(info->uid == uid))
+		return;
+
+	info->uid = uid;
+
+	pwd = getpwuid(uid);
+
+	if(pwd && pwd->pw_name)
+		username = g_strdup(pwd->pw_name);
+	else
+		username = g_strdup_printf("%u", (unsigned)uid);
+
+	/* don't free, because info->user belongs to procdata->users */
+	info->user = g_string_chunk_insert_const(procdata->users, username);
+
+	g_free(username);
+}
+
+
+
 static void
 get_process_memory_info(ProcInfo *info)
 {
@@ -427,13 +488,77 @@ find_parent (ProcData *procdata, guint pid)
 }
 
 
+
+static char *
+format_duration_for_display (double d)
+{
+	double minutes, seconds, centiseconds;
+
+	centiseconds = 100.0 * modf(d, &seconds);
+
+	if(seconds < 60.0)
+	{
+		minutes = 0.0;
+	}
+	else
+	{
+		minutes = seconds / 60.0;
+		seconds = fmod(seconds, 60.0);
+	}
+
+	return g_strdup_printf(
+		"%02u:%02u.%02u",
+		(unsigned) minutes,
+		(unsigned) seconds,
+		(unsigned) centiseconds);
+}
+
+
+static void
+update_info_mutable_cols(GtkTreeStore *store, ProcData *procdata, ProcInfo *info)
+{
+	gchar *mem, *vmsize, *memres, *memshared, *memrss, *memxserver, *cpu_time;
+
+	mem	   = SI_gnome_vfs_format_file_size_for_display (info->mem);
+	vmsize	   = SI_gnome_vfs_format_file_size_for_display (info->vmsize);
+	memres	   = SI_gnome_vfs_format_file_size_for_display (info->memres);
+	memshared  = SI_gnome_vfs_format_file_size_for_display (info->memshared);
+	memrss	   = SI_gnome_vfs_format_file_size_for_display (info->memrss);
+	memxserver = SI_gnome_vfs_format_file_size_for_display (info->memxserver);
+
+	cpu_time = format_duration_for_display (info->cpu_time_last / procdata->frequency);
+
+	gtk_tree_store_set (store, &info->node,
+			    COL_STATUS, info->status,
+			    COL_USER, info->user,
+			    COL_MEM, mem,
+			    COL_VMSIZE, vmsize,
+			    COL_MEMRES, memres,
+			    COL_MEMSHARED, memshared,
+			    COL_MEMRSS, memrss,
+			    COL_MEMXSERVER, memxserver,
+			    COL_CPU, info->pcpu,
+			    COL_CPU_TIME, cpu_time,
+			    COL_NICE, info->nice,
+			    -1);
+
+	/* We don't bother updating COL_SECURITYCONTEXT as it can never change */
+	g_free (mem);
+	g_free (vmsize);
+	g_free (memres);
+	g_free (memshared);
+	g_free (memrss);
+	g_free (memxserver);
+	g_free (cpu_time);
+}
+
+
+
 void
 insert_info_to_tree (ProcInfo *info, ProcData *procdata)
 {
 	GtkTreeModel *model;
-	GtkTreeIter row;
 	gchar *name;
-	gchar *mem, *vmsize, *memres, *memshared, *memrss, *memxserver;
 
 	/* Don't show process if it is not running */
 	if ((procdata->config.whose_process == ACTIVE_PROCESSES) &&
@@ -460,7 +585,7 @@ insert_info_to_tree (ProcInfo *info, ProcData *procdata)
 	if (info->parent && procdata->config.show_tree && info->parent->is_visible) {
 		GtkTreePath *parent_node = gtk_tree_model_get_path (model, &info->parent->node);
 
-		gtk_tree_store_insert (GTK_TREE_STORE (model), &row, &info->parent->node, 0);
+		gtk_tree_store_insert (GTK_TREE_STORE (model), &info->node, &info->parent->node, 0);
 		if (!gtk_tree_view_row_expanded (GTK_TREE_VIEW (procdata->tree), parent_node))
 			gtk_tree_view_expand_row (GTK_TREE_VIEW (procdata->tree),
 						  parent_node,
@@ -469,48 +594,27 @@ insert_info_to_tree (ProcInfo *info, ProcData *procdata)
 		gtk_tree_path_free (parent_node);
 	}
 	else
-		gtk_tree_store_insert (GTK_TREE_STORE (model), &row, NULL, 0);
-
-	mem = gnome_vfs_format_file_size_for_display (info->mem);
-	vmsize = gnome_vfs_format_file_size_for_display (info->vmsize);
-	memres = gnome_vfs_format_file_size_for_display (info->memres);
-	memshared = gnome_vfs_format_file_size_for_display (info->memshared);
-	memrss = gnome_vfs_format_file_size_for_display (info->memrss);
-	memxserver = gnome_vfs_format_file_size_for_display (info->memxserver);
+		gtk_tree_store_insert (GTK_TREE_STORE (model), &info->node, NULL, 0);
 
 	/* COL_POINTER must be set first, because GtkTreeStore
 	 * will call sort_ints as soon as we set the column
 	 * that we're sorting on.
 	 */
 
-	gtk_tree_store_set (GTK_TREE_STORE (model), &row,
+	gtk_tree_store_set (GTK_TREE_STORE (model), &info->node,
 			    COL_POINTER, info,
 			    COL_PIXBUF, info->pixbuf,
 			    COL_NAME, name,
 			    COL_ARGS, info->arguments,
-			    COL_USER, info->user,
-			    COL_STATUS, info->status,
-			    COL_MEM, mem,
-			    COL_VMSIZE, vmsize,
-			    COL_MEMRES, memres,
-			    COL_MEMSHARED, memshared,
-			    COL_MEMRSS, memrss,
-			    COL_MEMXSERVER, memxserver,
-			    COL_CPU, info->pcpu,
 			    COL_PID, info->pid,
-			    COL_NICE, info->nice,
 			    COL_SECURITYCONTEXT, info->security_context,
 			    -1);
-	g_free (mem);
-	g_free (vmsize);
-	g_free (memres);
-	g_free (memshared);
-	g_free (memrss);
-	g_free (memxserver);
-	g_free (name);
 
-	info->node = row;
+	update_info_mutable_cols(GTK_TREE_STORE (model), procdata, info);
+
 	info->is_visible = TRUE;
+
+	g_free(name);
 }
 
 
@@ -587,7 +691,7 @@ remove_info_from_list (ProcInfo *info, ProcData *procdata)
 	/* Remove from list */
 	procdata->info = g_list_remove (procdata->info, info);
 	g_hash_table_remove(procdata->pids, GINT_TO_POINTER(info->pid));
-	proctable_free_info (info);
+	proctable_free_info (procdata, info);
 }
 
 
@@ -618,7 +722,6 @@ update_info (ProcData *procdata, ProcInfo *info)
 	if (info->is_visible) {
 		GdkRectangle rect, vis_rect;
 		GtkTreePath *path;
-		gchar *mem, *vmsize, *memres, *memshared, *memrss, *memxserver;
 
 		GtkTreeModel *model;
 		glibtop_proc_uid procuid;
@@ -628,6 +731,7 @@ update_info (ProcData *procdata, ProcInfo *info)
 		glibtop_get_proc_time (&proctime, info->pid);
 
 		get_process_memory_info(info);
+		get_process_user(procdata, info, procstate.uid);
 
 		info->pcpu = (proctime.rtime - info->cpu_time_last) * 100 / total_time;
 		info->pcpu = MIN(info->pcpu, 100);
@@ -649,31 +753,7 @@ update_info (ProcData *procdata, ProcInfo *info)
 		if ((rect.y < 0) || (rect.y > vis_rect.height))
 			return;
 
-		mem = gnome_vfs_format_file_size_for_display (info->mem);
-		vmsize = gnome_vfs_format_file_size_for_display (info->vmsize);
-		memres = gnome_vfs_format_file_size_for_display (info->memres);
-		memshared = gnome_vfs_format_file_size_for_display (info->memshared);
-		memrss = gnome_vfs_format_file_size_for_display (info->memrss);
-		memxserver = gnome_vfs_format_file_size_for_display (info->memxserver);
-
-		gtk_tree_store_set (GTK_TREE_STORE (model), &info->node,
-				    COL_STATUS, info->status,
-				    COL_MEM, mem,
-				    COL_VMSIZE, vmsize,
-				    COL_MEMRES, memres,
-				    COL_MEMSHARED, memshared,
-				    COL_MEMRSS, memrss,
-				    COL_MEMXSERVER, memxserver,
-				    COL_CPU, info->pcpu,
-				    COL_NICE, info->nice,
-				    -1);
-		/* We don't bother updating COL_SECURITYCONTEXT as it can never change */
-		g_free (mem);
-		g_free (vmsize);
-		g_free (memres);
-		g_free (memshared);
-		g_free (memrss);
-		g_free (memxserver);
+		update_info_mutable_cols(GTK_TREE_STORE (model), procdata, info);
 	}
 }
 
@@ -681,44 +761,28 @@ update_info (ProcData *procdata, ProcInfo *info)
 static ProcInfo *
 get_info (ProcData *procdata, gint pid)
 {
-	ProcInfo *info = g_new0 (ProcInfo, 1);
+	ProcInfo *info;
 	glibtop_proc_state procstate;
 	glibtop_proc_time proctime;
 	glibtop_proc_uid procuid;
 	glibtop_proc_args procargs;
-	struct passwd *pwd;
-	gchar *arguments;
+	gchar** arguments;
+
+	info = g_chunk_new0(ProcInfo, procdata->procinfo_allocator);
 
 	info->pid = pid;
+	info->uid = -1;
 
 	glibtop_get_proc_state (&procstate, pid);
-	pwd = getpwuid (procstate.uid);
-	glibtop_get_proc_time (&proctime, pid);
 	glibtop_get_proc_uid (&procuid, pid);
 	glibtop_get_proc_time (&proctime, pid);
+	arguments = glibtop_get_proc_argv (&procargs, pid, 0);
 
-	arguments = glibtop_get_proc_args (&procargs, pid, 0);
-	get_process_name (info, procstate.cmd, arguments);
+	get_process_name (info, procstate.cmd, arguments[0]);
+	get_process_user (procdata, info, procstate.uid);
 
-	if (arguments)
-	{
-		guint i;
-
-		for (i = 0; i < procargs.size; i++)
-		{
-			if (!arguments[i])
-				arguments[i] = ' ';
-		}
-		/* steals arguments */
-		info->arguments = arguments;
-	}
-	else
-		info->arguments = g_strdup ("");
-
-	if (pwd && pwd->pw_name)
-		info->user = g_strdup(pwd->pw_name);
-	else
-		info->user = NULL;
+	info->arguments = g_strjoinv(" ", arguments);
+	g_strfreev(arguments);
 
 	info->pcpu = 0;
 	info->cpu_time_last = proctime.rtime;
@@ -733,38 +797,11 @@ get_info (ProcData *procdata, gint pid)
 	info->parent = find_parent (procdata, procuid.ppid);
 	if (info->parent) {
 		info->parent->children = g_list_prepend (info->parent->children, info);
-		if(g_strcasecmp (info->name, info->parent->name) == 0
+		if(g_str_equal(info->name, info->parent->name)
 		   && info->parent->mem == info->mem)
 			info->is_thread = TRUE;
 	}
 
-#if 0
-	if (parentinfo) {
-	/* Ha Ha - don't expand different threads - check to see if parent has
-	** same name and same mem usage - I don't know if this is too smart though.
-	*/
-
-		if (!g_strcasecmp (info->name, parentinfo->name) &&
-		    ( parentinfo->mem == info->mem))
-		{
-			info->is_thread = TRUE;
-		}
-		else
-			info->is_thread = FALSE;
-
-		if (parentinfo->is_visible) {
-			info->parent_node = parentinfo->node;
-			info->has_parent = TRUE;
-		}
-		else
-			info->has_parent = FALSE;
-	}
-	else {
-		info->has_parent = FALSE;
-		info->is_thread = FALSE;
-	}
-#endif
-
 	info->is_visible = FALSE;
 
 	return info;
@@ -887,6 +924,12 @@ proctable_update_list (ProcData * const procdata)
 void
 proctable_update_all (ProcData * const procdata)
 {
+	char* string;
+
+	string = make_loadavg_string();
+	gtk_label_set_text (GTK_LABEL(procdata->loadavg), string);
+	g_free (string);
+
 	proctable_update_list (procdata);
 
 	if (procdata->config.show_more_info)
@@ -917,7 +960,7 @@ proctable_free_table (ProcData * const procdata)
 	while (list)
 	{
 		ProcInfo *info = list->data;
-		proctable_free_info (info);
+		proctable_free_info (procdata, info);
 		list = g_list_next (list);
 	}
 
@@ -929,88 +972,18 @@ proctable_free_table (ProcData * const procdata)
 }
 
 
-void
-proctable_search_table (ProcData *procdata, gchar *string)
+
+char*
+make_loadavg_string(void)
 {
-	GList *list = procdata->info;
-	GtkWidget *dialog;
-	GtkTreeModel *model;
-	static gint increment = 0;
-	gint index;
-	static gchar *last = NULL;
+	glibtop_loadavg buf;
 
-	if (!g_strcasecmp (string, ""))
-		return;
+	glibtop_get_loadavg(&buf);
 
-	model = gtk_tree_view_get_model (GTK_TREE_VIEW (procdata->tree));
-
-	if (!last)
-		last = g_strdup (string);
-	else if (g_strcasecmp (string, last)) {
-		increment = 0;
-		g_free (last);
-		last = g_strdup (string);
-	}
-	else
-		increment ++;
-
-	index = increment;
-
-	while (list)
-	{
-		ProcInfo *info = list->data;
-		if (strstr (info->name, string) && info->is_visible)
-		{
-			GtkTreePath *node = gtk_tree_model_get_path (model, &info->node);
-
-			if (index == 0) {
-				gtk_tree_view_set_cursor (GTK_TREE_VIEW (procdata->tree),
-							  node,
-							  NULL,
-							  FALSE);
-				return;
-			}
-			else
-				index --;
-
-			gtk_tree_path_free (node);
-		}
-
-		if (info->user && strstr (info->user, string) && info->is_visible)
-		{
-			GtkTreePath *node = gtk_tree_model_get_path (model, &info->node);
-
-			if (index == 0) {
-				gtk_tree_view_set_cursor (GTK_TREE_VIEW (procdata->tree),
-							  node,
-							  NULL,
-							  FALSE);
-				return;
-			}
-			else
-				index --;
-
-			gtk_tree_path_free (node);
-		}
-
-		list = g_list_next (list);
-	}
-
-	if (index == increment) {
-		dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
-						 GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
-						 _("%s could not be found."), string,
-						 NULL);
-		gtk_dialog_run (GTK_DIALOG (dialog));
-		gtk_widget_destroy (dialog);
-	}
-	else {
-		/* no more cases found. Start the search anew */
-		increment = -1;
-		proctable_search_table (procdata, string);
-		return;
-	}
-
-	increment --;
+	return g_strdup_printf(
+		_("Load averages for the last 1, 5, 15 minutes: "
+		  "%0.2f, %0.2f, %0.2f"),
+		buf.loadavg[0],
+		buf.loadavg[1],
+		buf.loadavg[2]);
 }
-
