@@ -20,6 +20,9 @@
 #ifndef _PROCMAN_PROCTABLE_H_
 #define _PROCMAN_PROCTABLE_H_
 
+#include <glib.h>
+#include <gtk/gtk.h>
+#include "procman.h"
 
 enum
 {
@@ -33,6 +36,7 @@ enum
 	COL_MEMRSS,
 	COL_MEMXSERVER,
 	COL_CPU,
+	COL_CPU_TIME,
 	COL_NICE,
 	COL_PID,
 	COL_SECURITYCONTEXT,
@@ -52,7 +56,7 @@ ProcInfo *	proctable_find_process (guint pid, ProcData *procdata) G_GNUC_INTERNA
 void		proctable_update_all (ProcData *data) G_GNUC_INTERNAL;
 void		proctable_clear_tree (ProcData *data) G_GNUC_INTERNAL;
 void		proctable_free_table (ProcData *data) G_GNUC_INTERNAL;
-void		proctable_search_table (ProcData *procdata, gchar *string) G_GNUC_INTERNAL;
 
+char*		make_loadavg_string(void) G_GNUC_INTERNAL;
 
 #endif /* _PROCMAN_PROCTABLE_H_ */
